import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import fs from 'fs';
import http from 'http';
import https from 'https';
import util from 'util';
import { toArrayBuffer } from './utils/to-array-buffer.node';
import decodeDataUri from './utils/decode-data-uri.node';
import { concatenateReadStream } from './utils/stream-utils.node';
const DEFAULT_OPTIONS = {
  dataType: 'arraybuffer'
};

const isDataURL = url => url.startsWith('data:');

const isRequestURL = url => url.startsWith('http:') || url.startsWith('https:');

export async function readFile(url, options = {}) {
  options = getReadFileOptions(options);

  if (isDataURL(url)) {
    const {
      arrayBuffer
    } = decodeDataUri(url);
    return Promise.resolve(arrayBuffer);
  }

  if (isRequestURL(url)) {
    return new Promise((resolve, reject) => {
      options = _objectSpread({}, new URL(url), {}, options);
      const request = url.startsWith('https:') ? https.request : http.request;
      request(url, response => concatenateReadStream(response).then(resolve, reject));
    });
  }

  const queryIndex = url && url.lastIndexOf('?');
  url = queryIndex >= 0 ? url.substr(0, queryIndex) : url;
  const readFileAsync = util.promisify(fs.readFile);
  const buffer = await readFileAsync(url, options);
  return buffer instanceof Buffer ? toArrayBuffer(buffer) : buffer;
}
export async function createReadStream(url, options) {
  if (isDataURL(url)) {
    return decodeDataUri(url);
  }

  if (!isRequestURL(url)) {
    return fs.createReadStream(url, options);
  }

  return new Promise((resolve, reject) => {
    options = _objectSpread({}, new URL(url), {}, options);
    const request = url.startsWith('https:') ? https.request : http.request;
    request(url, response => resolve(response));
  });
}

function getReadFileOptions(options = {}) {
  options = Object.assign({}, DEFAULT_OPTIONS, options);
  options.responseType = options.responseType || options.dataType;

  if (fs) {
    options.encoding = options.encoding || (options.dataType === 'text' ? 'utf8' : null);
  }

  return options;
}
//# sourceMappingURL=read-file.node.js.map